@@ -116,7 +116,7 @@
 using namespace KgpgCore;
 
 KeysManager::KeysManager(QWidget *parent)
-           : KXmlGuiWindow(parent)
+           : KXmlGuiWindow(parent, 0)
 {
     new KeyAdaptor(this);
     QDBusConnection::sessionBus().registerObject("/KeyInterface", this);
@@ -509,7 +509,7 @@ void KeysManager::slotGenerateKeyProcess(KgpgInterface *)
     pop = new KPassivePopup(this);
     pop->setTimeout(0);
 
-    KVBox *passiveBox = pop->standardView(i18n("Generating new key pair."), QString(), Images::kgpg(), 0);
+    KVBox *passiveBox = pop->standardView(i18n("Generating new key pair."), QString(), Images::kgpg());
 
     QMovie anim(KStandardDirs::locate("appdata", "pics/kgpg_anim.gif"));
     QLabel *text1 = new QLabel(passiveBox);
@@ -536,6 +536,9 @@ void KeysManager::slotGenerateKeyDone(int res, KgpgInterface *interface, const Q
     delete interface;
     changeMessage(i18nc("Application ready for user input", "Ready"), 0);
 
+    delete pop;
+    pop = NULL;
+
     if (res == 1)
     {
         QString infomessage = i18n("Generating new key pair");
@@ -602,9 +605,6 @@ void KeysManager::slotGenerateKeyDone(int res, KgpgInterface *interface, const Q
         page->show();
         keyCreated->setMainWidget(page);
 
-        delete pop;
-        pop = 0;
-
         keyCreated->exec();
 
         KeyListViewItem *newdef = keysList2->findItemByKeyId(fingerprint);
@@ -1147,9 +1147,9 @@ void KeysManager::closeEvent (QCloseEvent *e)
 {
     // kapp->ref(); // prevent KXmlGuiWindow from closing the app
     // KXmlGuiWindow::closeEvent(e);
-    e->accept();
-    // hide();
-    // e->ignore();
+    // e->accept();
+    hide();
+    e->ignore();
 }
 
 void KeysManager::showKeyServer()
