@@ -43,6 +43,8 @@ Sweeper::Sweeper()
 
    createGUI("sweeperui.rc");
 
+   setAutoSaveSettings();
+
    generalCLI     = new QTreeWidgetItem(QStringList() << i18nc("General system content", "General"));
    sw->addTopLevelItem(generalCLI);
    webbrowsingCLI = new QTreeWidgetItem(QStringList() << i18nc("Web browsing content", "Web Browsing"));
@@ -61,11 +63,14 @@ Sweeper::Sweeper()
    setCentralWidget(cleaningDialog);
    new KsweeperAdaptor(this);
    QDBusConnection::sessionBus().registerObject("/ksweeper", this);
+
+   load();
 }
 
 
 Sweeper::~Sweeper()
 {
+   save();
 }
 
 
@@ -79,7 +84,7 @@ void Sweeper::load()
    QLinkedList<PrivacyAction*>::iterator itr;
 
    for (itr = checklist.begin(); itr != checklist.end(); ++itr) {
-      (*itr)->setCheckState(0, group.readEntry((*itr)->text(0), true) ? Qt::Checked : Qt::Unchecked);
+      (*itr)->setCheckState(0, group.readEntry((*itr)->configKey(), true) ? Qt::Checked : Qt::Unchecked);
    }
 
    delete c;
@@ -99,7 +104,7 @@ void Sweeper::save()
    QLinkedList<PrivacyAction*>::iterator itr;
 
    for (itr = checklist.begin(); itr != checklist.end(); ++itr) {
-      group.writeEntry((*itr)->text(0), (*itr)->checkState(0) == Qt::Checked);
+      group.writeEntry((*itr)->configKey(), (*itr)->checkState(0) == Qt::Checked);
    }
 
    group.sync();
